@@ -1,6 +1,5 @@
 # Copyright 2020 StackHut Limited (trading as Datapane)
 # SPDX-License-Identifier: Apache-2.0
-# flake8: noqa F401
 import os
 import sys
 from pathlib import Path
@@ -11,7 +10,7 @@ except ImportError:
     # NOTE - could use subprocess to get from git?
     __rev__ = "local"
 
-__version__ = "0.13.1"
+__version__ = "0.15.0"
 
 _TEST_ENV = bool(os.environ.get("DP_TEST_ENV", ""))
 _IN_PYTEST = "pytest" in sys.modules
@@ -22,25 +21,25 @@ _USING_CONDA = os.path.exists(os.path.join(sys.prefix, "conda-meta", "history"))
 
 
 # Other useful re-exports
-from .common.utils import enable_logging, log, _setup_dp_logging
+from .common.utils import _setup_dp_logging, enable_logging, log  # isort:skip  otherwise circular import issue
 
 # Public API re-exports
 from .client.api import (
+    HTML,
+    App,
     Attachment,
-    Media,
     BigNumber,
     Code,
     DataTable,
     Divider,
     Embed,
     Empty,
+    Environment,
     File,
-    Group,
     FontChoice,
     Formula,
-    HTML,
+    Group,
     Media,
-    Text,
     Page,
     PageLayout,
     Params,
@@ -51,25 +50,67 @@ from .client.api import (
     Result,
     Run,
     Schedule,
-    App,
     Select,
     SelectType,
     Table,
     Text,
     TextAlignment,
     Toggle,
-    Environment,
-    Visibility,
+    builtins,
     by_datapane,
-    signup,
+    hello_world,
     login,
     logout,
     ping,
-    hello_world,
-    builtins,
+    template,
 )
 from .client.config import init
-from .common.dp_types import DPMode, set_dp_mode, get_dp_mode
+from .common.dp_types import DPMode, get_dp_mode, set_dp_mode
+
+__all__ = [
+    "HTML",
+    "App",
+    "Attachment",
+    "BigNumber",
+    "Code",
+    "DataTable",
+    "Divider",
+    "Embed",
+    "Empty",
+    "Environment",
+    "File",
+    "FontChoice",
+    "Formula",
+    "Group",
+    "Media",
+    "Page",
+    "PageLayout",
+    "Params",
+    "Plot",
+    "Report",
+    "ReportFormatting",
+    "ReportWidth",
+    "Result",
+    "Run",
+    "Schedule",
+    "Select",
+    "SelectType",
+    "Table",
+    "Text",
+    "TextAlignment",
+    "Toggle",
+    "builtins",
+    "by_datapane",
+    "hello_world",
+    "login",
+    "logout",
+    "ping",
+    "template",
+    "_setup_dp_logging",
+    "enable_logging",
+    "log",
+]
+
 
 script_name = sys.argv[0]
 script_exe = Path(script_name).stem
@@ -87,7 +128,6 @@ if get_dp_mode() == DPMode.LIBRARY:
     init()
     # parse any commandline params
     from .client.utils import parse_command_line
-    from .client.api.runtime import Params
 
     config = parse_command_line()
     Params.replace(config)
