@@ -4,7 +4,7 @@ from packaging.specifiers import SpecifierSet
 from datapane.common import log
 
 # NOTE - need to update this and keep in sync with JS
-BOKEH_V_SPECIFIER = SpecifierSet("~=2.2.0")
+BOKEH_V_SPECIFIER = SpecifierSet("~=2.4.2")
 PLOTLY_V_SPECIFIER = SpecifierSet(">=4.0.0")
 FOLIUM_V_SPECIFIER = SpecifierSet(">=0.12.0")
 
@@ -21,10 +21,10 @@ try:
     from matplotlib.figure import Axes, Figure
 except ImportError:
 
-    class Axes:
+    class Axes:  # type: ignore
         pass
 
-    class Figure:
+    class Figure:  # type: ignore
         pass
 
 
@@ -37,10 +37,10 @@ try:
     _check_version("Bokeh", v.Version(bokeh.__version__), BOKEH_V_SPECIFIER)
 except ImportError:
 
-    class BLayout:
+    class BLayout:  # type: ignore
         pass
 
-    class BFigure:
+    class BFigure:  # type: ignore
         pass
 
 
@@ -52,7 +52,7 @@ try:
     _check_version("Plotly", v.Version(plotly.__version__), PLOTLY_V_SPECIFIER)
 except ImportError:
 
-    class PFigure:
+    class PFigure:  # type: ignore
         pass
 
 
@@ -64,5 +64,15 @@ try:
     _check_version("Folium", v.Version(folium.__version__), FOLIUM_V_SPECIFIER)
 except ImportError:
 
-    class Map:
+    class Map:  # type: ignore
+        pass
+
+
+# Plotapi (we don't check version as export to HTML string)
+try:
+    from plotapi import Visualisation
+
+except ImportError:
+
+    class Visualisation:  # type: ignore
         pass
