@@ -135,7 +135,7 @@ class BaseElement(ABC):
 
     @abstractmethod
     def _to_xml(self, s: BuilderState) -> BuilderState:
-        ...
+        pass
 
 
 Block = t.Union["Group", "Select", "DataBlock", "Empty"]
@@ -367,7 +367,7 @@ class DataBlock(BaseElement):
     ..note:: This class is not used directly.
     """
 
-    ...
+    pass
 
 
 class EmbeddedTextBlock(DataBlock):
@@ -433,7 +433,7 @@ class Text(EmbeddedTextBlock):
         """
 
         splits = re.split(r"\{\{(\w*)\}\}", self.content)
-        args = deque(args)
+        deque_args = deque(args)
         blocks = []
 
         for (i, x) in enumerate(splits):
@@ -444,7 +444,7 @@ class Text(EmbeddedTextBlock):
                     if x:
                         blocks.append(wrap_block(kwargs[x]))
                     else:
-                        blocks.append(wrap_block(args.popleft()))
+                        blocks.append(wrap_block(deque_args.popleft()))
                 except (IndexError, KeyError):
                     raise DPError(f"Unknown/missing object '{x}' referenced in Markdown format")
 
@@ -718,7 +718,7 @@ class Attachment(AssetBlock):
 
 class Plot(AssetBlock):
     """
-    Plot blocks store a Python-based plot object, including ones created by Altair, Plotly, Matplotlib, Bokeh, and Folium,
+    Plot blocks store a Python-based plot object, including ones created by Altair, Plotly, Matplotlib, Bokeh, Folium, and PlotAPI,
     for interactive display in your report when viewed in the browser.
     """
 
