@@ -4,20 +4,20 @@ Datapane Reports Object
 Describes the `Report` object and included APIs for saving and uploading them.
 """
 import dataclasses as dc
-import random
 import typing as t
 import webbrowser
 from base64 import b64encode
-from enum import Enum, IntEnum
+from enum import Enum
 from functools import reduce
 from os import path as osp
 from pathlib import Path
 from uuid import uuid4
 
 import importlib_resources as ir
-from jinja2 import Environment, FileSystemLoader, Markup, Template, contextfunction
+from jinja2 import Environment, FileSystemLoader, Template, contextfunction
 from lxml import etree
 from lxml.etree import Element, _Element
+from markupsafe import Markup  # used by Jinja
 
 from datapane.client import config as c
 from datapane.client.analytics import _NO_ANALYTICS, capture, capture_event
@@ -25,45 +25,22 @@ from datapane.client.api.common import DPTmpFile, Resource
 from datapane.client.api.dp_object import DPObjectRef
 from datapane.client.api.runtime import _report
 from datapane.client.utils import DPError, InvalidReportError, display_msg
-from datapane.common import NPath, dict_drop_empty, log, timestamp
+from datapane.common import SDict, dict_drop_empty, log, timestamp
 from datapane.common.report import local_report_def, validate_report_doc
-from datapane.common.utils import process_notebook
 
-from .blocks import (
-    BaseElement,
-    Block,
-    BlockList,
-    BlockOrPrimitive,
-    BuilderState,
-    E,
-    Group,
-    Page,
-    PageOrPrimitive,
-    wrap_block,
-)
+from .blocks import BlockOrPrimitive, BuilderState, E, Page, PageOrPrimitive
 
 local_post_xslt = etree.parse(str(local_report_def / "local_post_process.xslt"))
 local_post_transform = etree.XSLT(local_post_xslt)
 
 # only these types will be documented by default
-__all__ = ["Report", "ReportWidth", "Visibility"]
+__all__ = ["Report", "ReportWidth"]
 
 __pdoc__ = {
     "Report.endpoint": False,
 }
 
 
-class Visibility(IntEnum):
-    """The report visibility type, set for reports on Datapane Studio
-
-    ..note:: This is ignored on Datapane Enterprise, reports are always private
-    """
-
-    DEFAULT = 1  # not listed on the users portfolio
-    PORTFOLIO = 2  # above + added to user's portfolio page
-    PRIVATE = 3  # private to owner
-
-
 class ReportWidth(Enum):
     """The document width"""
 
@@ -121,8 +98,8 @@ class ReportFormatting:
 
 
 @contextfunction
-def include_raw(ctx, name):
-    """ Normal jinja2 {% include %} doesn't escape {{...}} which appear in React's source code """
+def include_raw(ctx, name) -> Markup:  # noqa: ANN001
+    """Normal jinja2 {% include %} doesn't escape {{...}} which appear in React's source code"""
     env = ctx.environment
     # Escape </script> to prevent 3rd party JS terminating the local report bundle.
     # Note there's an extra "\" because it needs to be escaped at both the python and JS level
@@ -131,7 +108,7 @@ def include_raw(ctx, name):
 
 
 class ReportFileWriter:
-    """ Collects data needed to display a local report document, and generates the local HTML """
+    """Collects data needed to display a local report document, and generates the local HTML"""
 
     template: t.Optional[Template] = None
     assets: Path
@@ -139,7 +116,7 @@ class ReportFileWriter:
     dev_mode: bool = False
 
     def _setup_template(self):
-        """ Jinja template setup for local rendering """
+        """Jinja template setup for local rendering"""
         # check we have the FE files, abort if not
         self.assets = ir.files("datapane.resources.local_report")
         if not (self.assets / "local-report-base.css").exists():
@@ -170,11 +147,9 @@ class ReportFileWriter:
         if not self.template:
             self._setup_template()
 
-        # template.html inlines the report doc with backticks so we need to escape any inside the doc
-        report_doc_esc = report_doc.replace("`", r"\`")
         report_id = uuid4().hex
         r = self.template.render(
-            report_doc=report_doc_esc,
+            report_doc=report_doc,
             report_width=formatting.width.value,
             report_name=name,
             report_author=author,
@@ -203,7 +178,7 @@ class Report(DPObjectRef):
 
     _tmp_report: t.Optional[Path] = None  # Temp local report
     _local_writer = ReportFileWriter()
-    _preview_file: str = DPTmpFile(f"{uuid4().hex}.html")
+    _preview_file = DPTmpFile(f"{uuid4().hex}.html")
     list_fields: t.List[str] = ["name", "web_url", "project"]
 
     endpoint: str = "/reports/"
@@ -270,7 +245,7 @@ class Report(DPObjectRef):
         # add optional Meta
         if embedded:
             meta = E.Meta(
-                E.Author(c.config.username or author),
+                E.Author(author or ""),
                 E.CreatedOn(timestamp()),
                 E.Title(title),
                 E.Description(description),
@@ -284,15 +259,16 @@ class Report(DPObjectRef):
         title: str = "Title",
         description: str = "Description",
         author: str = "Anonymous",
-        check_empty: bool = True,
+        validate: bool = True,
     ) -> t.Tuple[str, t.List[Path]]:
         """Generate a report for saving/uploading"""
         report_doc, attachments = self._to_xml(embedded, title, description, author)
 
         # post_process and validate
         processed_report_doc = local_post_transform(report_doc, embedded="true()" if embedded else "false()")
-        validate_report_doc(xml_doc=processed_report_doc)
-        self._report_status_checks(processed_report_doc, embedded, check_empty)
+        if validate:
+            validate_report_doc(xml_doc=processed_report_doc)
+            self._report_status_checks(processed_report_doc, embedded)
 
         # convert to string
         report_str = etree.tounicode(processed_report_doc)
@@ -300,7 +276,7 @@ class Report(DPObjectRef):
         # log.debug(report_str)
         return (report_str, attachments)
 
-    def _report_status_checks(self, processed_report_doc: etree._ElementTree, embedded: bool, check_empty: bool):
+    def _report_status_checks(self, processed_report_doc: etree._ElementTree, embedded: bool):
         # check for any unsupported local features, e.g. DataTable
         # NOTE - we could eventually have different validators for local and uploaded reports
         if embedded:
@@ -308,19 +284,12 @@ class Report(DPObjectRef):
 
         # Report checks
         # TODO - validate at least a single element
-        asset_blocks = processed_report_doc.xpath("count(/Report/Pages//*)")
-        if asset_blocks < 3 and check_empty:
+        asset_blocks = processed_report_doc.xpath("count(/Report/Pages/Page/*)")
+        if asset_blocks == 0:
             raise InvalidReportError("Empty report - must contain at least one asset/block")
-        elif c.config.is_public:
-            # only nudge public users
-            if asset_blocks < 4:
-                display_msg(
-                    "Your report only contains a single element - did you know you can include additional plots, tables and text in a single report? More info {url:l}",
-                    url="https://docs.datapane.com/reports/blocks/layout-pages-and-selects",
-                )
 
     @property
-    def edit_url(self):
+    def edit_url(self) -> str:
         return f"{self.web_url}edit/"
 
     ############################################################################
@@ -331,19 +300,18 @@ class Report(DPObjectRef):
         name: str,
         description: str = "",
         source_url: str = "",
-        visibility: t.Union[Visibility, str] = "",
+        publicly_visible: bool = False,
         tags: t.List[str] = None,
         project: t.Optional[str] = None,
-        source_file: t.Optional[NPath] = None,
         formatting: t.Optional[ReportFormatting] = None,
+        overwrite: bool = False,
         **kwargs,
     ) -> None:
         # TODO - clean up arg handling
         # process params
         tags = tags or []
-        visibility_str = visibility.upper() if isinstance(visibility, str) else visibility.name
 
-        formatting_kwargs = {}
+        formatting_kwargs: SDict = {}
         if formatting:
             formatting_kwargs.update(
                 width=formatting.width.value,
@@ -360,7 +328,7 @@ class Report(DPObjectRef):
             description=description,
             tags=tags,
             source_url=source_url,
-            visibility=visibility_str,
+            publicly_visible=publicly_visible,
             project=project,
             **formatting_kwargs,
         )
@@ -372,13 +340,7 @@ class Report(DPObjectRef):
         report_str, attachments = self._gen_report(embedded=False, title=name, description=description)
         files = dict(attachments=attachments)
 
-        # create empty temp file to potentially store stripped down notebook
-        with DPTmpFile(".ipynb") as output_file:
-            if source_file:
-                # strip the output of original notebook and store in temp file
-                process_notebook(Path(source_file), output_file.file)
-                files["source_file"] = [output_file.file]
-            res = Resource(self.endpoint).post_files(files, document=report_str, **kwargs)
+        res = Resource(self.endpoint).post_files(files, overwrite=overwrite, document=report_str, **kwargs)
 
         # Set dto based on new URL
         self.url = res.url
@@ -392,12 +354,12 @@ class Report(DPObjectRef):
         name: str,
         description: str = "",
         source_url: str = "",
-        visibility: t.Union[Visibility, str] = "",
+        publicly_visible: bool = False,
         tags: t.List[str] = None,
         project: t.Optional[str] = None,
-        source_file: t.Optional[NPath] = None,
         open: bool = False,
         formatting: t.Optional[ReportFormatting] = None,
+        overwrite: bool = False,
         **kwargs,
     ) -> None:
         """
@@ -407,98 +369,36 @@ class Report(DPObjectRef):
             name: The document name - can include spaces, caps, symbols, etc., e.g. "Profit & Loss 2020"
             description: A high-level description for the document, this is displayed in searches and thumbnails
             source_url: A URL pointing to the source code for the document, e.g. a GitHub repo or a Colab notebook
-            visibility: "UNLISTED" (default), "PRIVATE", or "PUBLISHED" (for studio product only, ignored on enterprise)
+            publicly_visible: Visible to anyone with the link
             tags: A list of tags (as strings) used to categorise your document
-            project: Project to add the report to (Teams only)
-            source_file: Path of jupyter notebook file to upload
+            project: Project to add the report to
             open: Open the file in your browser after creating
             formatting: Set the basic styling for your report
+            overwrite: Overwrite the report
         """
 
         display_msg("Uploading report and associated data - *please wait...*")
 
         self._upload_report(
-            name, description, source_url, visibility, tags, project, source_file, formatting=formatting, **kwargs
+            name,
+            description,
+            source_url,
+            publicly_visible,
+            tags,
+            project,
+            formatting=formatting,
+            overwrite=overwrite,
+            **kwargs,
         )
 
         if open:
             webbrowser.open_new_tab(self.web_url)
 
         display_msg(
-            "Report successfully uploaded. View and share your report {web_url:l}, or edit your report {edit_url:l}.",
+            "Report successfully uploaded. View and share your report at {web_url:l}.",
             web_url=self.web_url,
-            edit_url=self.edit_url,
         )
 
-    def update_assets(
-        self,
-        *arg_blocks: Block,
-        blocks: t.Union[BlockDict, BlockList] = None,
-        open: bool = False,
-        **kw_blocks: BlockOrPrimitive,
-    ) -> None:
-        """
-        Upload updated plots, text, tables, and files for a report.
-        Blocks can be created with the `name` parameter, if not set, one can be provided here using keyword args.
-        Use the blocks dict parameter to add a dynamically generated set of named blocks, useful when working in Jupyter
-
-        Args:
-            *arg_blocks: List of blocks to add to document, these must be wrapped, e.g. using dp.DataTable(df) instead of df
-            blocks: Allows providing the document blocks as a single list/dictionary of named blocks
-            open: Open the report in your browser for editing after updating
-            **kw_blocks: Keyword argument set of blocks, whose block name will be that given in the keyword
-
-        Returns:
-            None
-
-        ..tip:: Blocks can be passed using either arg parameters or the `blocks` kwarg as a dictionary, e.g.
-          `report.update_assets(my_plot=plot, my_table=table)` or `report.update_assets(blocks={"my_plot": plot, "my_table":table})`
-
-        ..tip:: Create a dictionary first to hold your blocks to edit them dynamically, for instance when using Jupyter, and use the `blocks` parameter
-        """
-        # set the blocks
-        def _conv_block(block: BlockOrPrimitive, name: t.Optional[str] = None) -> Block:
-            x = wrap_block(block)
-            x._set_name(name)
-            return x
-
-        _blocks: BlockList
-        if isinstance(blocks, dict):
-            _blocks = [_conv_block(b, n) for (n, b) in blocks.items()]
-        elif isinstance(blocks, list):
-            _blocks = [_conv_block(b, None) for b in blocks]
-        else:
-            # use arg and kw blocks
-            _blocks = [_conv_block(b, None) for b in arg_blocks]
-            _blocks.extend([_conv_block(b, n) for (n, b) in kw_blocks.items()])
-
-        # Validity checks
-        if not _blocks:
-            raise DPError("No blocks provided to update")
-        # TODO - use typeguard
-        assert all(isinstance(x, BaseElement) for x in _blocks), "Please use kwarg syntax to upload unwrapped asses"
-        assert all(x.name for x in _blocks), "Please ensure all blocks have a name parameter set, or use kwarg syntax"
-
-        # set the pages
-        self.pages = [Page(blocks=[Group(blocks=_blocks)])]
-
-        # generate the report and upload
-        report_str, attachments = self._gen_report(embedded=False)
-        files = dict(attachments=attachments)
-        # post to the custom endpoint
-        Resource(f"{self.url}update_assets/").post_files(files, document=report_str, name=self.name)
-        self.refresh()
-
-        display_msg(
-            "Successfully updated report assets  - you can edit and format {edit_url:l}, and view the final report {web_url:l}",
-            web_url=self.web_url,
-            edit_url=self.edit_url,
-        )
-
-        if open:
-            webbrowser.open_new_tab(self.edit_url)
-        return self
-
     ############################################################################
     # Local saved reports
     def _save(
@@ -521,14 +421,7 @@ class Report(DPObjectRef):
             formatting=formatting,
         )
 
-        if c.config.is_anonymous:
-            display_msg(
-                "Report saved to ./{path}. To upload and share your report, create a free Datapane account by running `{signup:cmd}`.",
-                path=path,
-                signup="datapane signup",
-            )
-        else:
-            display_msg(f"Report saved to ./{path}")
+        display_msg(f"Report saved to ./{path}")
 
         if open:
             path_uri = f"file://{osp.realpath(osp.expanduser(path))}"
@@ -557,17 +450,10 @@ class Report(DPObjectRef):
         report_id = self._save(path, open, name, author, formatting)
         capture("CLI Report Save", report_id=report_id)
 
-        # feedback form
-        if random.random() < 0.1:
-            display_msg(
-                "How is your experience of Datapane? Please take two minutes to answer our anonymous product survey {url:l}",
-                url="https://bit.ly/3lWjRlr",
-            )
-
     @capture_event("CLI Report Preview")
     def preview(
         self,
-        open: True,
+        open: bool,
         formatting: t.Optional[ReportFormatting] = None,
     ) -> None:
         """Preview the report in a new browser window.
