@@ -26,7 +26,7 @@ APP_DIR.mkdir(parents=True, exist_ok=True)
 DEFAULT_ENV = "default"
 DEFAULT_SERVER = "https://datapane.com"
 DEFAULT_TOKEN = "TOKEN_HERE"
-LATEST_VERSION = 3
+LATEST_VERSION = 4
 
 
 # TODO - wrap into a singleton object that includes callable?
@@ -36,24 +36,28 @@ class Config:
     """
     Global config read from config file
 
-    Version is set to 1 when loading from file, then we pass into out upgrade function to bring it to latest
+    Versioning
+    - for b/c from before versioning config file, we set version to 1 if doesn't exist
+    - else we set it to latest version for a new config via post_init hook
+    - only on loading a config file do we run the upgrade function
     """
 
     server: str = DEFAULT_SERVER
     token: str = DEFAULT_TOKEN
-    username: str = ""
+    email: str = ""
     session_id: str = dc.field(default_factory=lambda: uuid.uuid4().hex)
-    version: int = 1  # if version doesn't exist in file
+    version: int = 1  # for b/c if version doesn't exist in file, set to latest in post_init hook
     completed_action: bool = False  # only active on first action
 
     from_file: dc.InitVar[bool] = False
 
-    _env: t.ClassVar[Optional[str]]
-    _path: t.ClassVar[Optional[Path]]
+    _env: Optional[str] = None
+    _path: Optional[Path] = None
 
     def __post_init__(self, from_file: bool):
         self.server = self.server.rstrip("/")  # server should be a valid origin
         if not from_file:
+            # set to latest if generating config file
             self.version = LATEST_VERSION
 
     @property
@@ -66,7 +70,7 @@ class Config:
 
     @property
     def is_authenticated(self) -> bool:
-        return self.token != DEFAULT_TOKEN  # or bool(self.username)
+        return self.token != DEFAULT_TOKEN  # or bool(self.email)
 
     @property
     def is_anonymous(self) -> bool:
@@ -85,11 +89,12 @@ class Config:
 
         # load config obj from file
         c_yaml["from_file"] = True
+
+        # NOTE - type checker doesn't like us setting class variables on instance
         config = dacite.from_dict(Config, c_yaml)
         config._env = env
         config._path = config_f
         log.debug(f"Loaded client environment from {config._path}")
-
         # check if stored file is out of date
         config.upgrade_config_format()
 
@@ -109,11 +114,16 @@ class Config:
         assert env or self._path
 
         if env:
+            # NOTE - type checker doesn't like us setting class variables on instance
+            # don't think this will cause issues
             self._env = env
             self._path = self.get_config_file(env)
 
         with self._path.open("w") as f:
-            yaml.safe_dump(dc.asdict(self), f)
+            config_dictionary = dc.asdict(self)
+            config_dictionary["_path"] = None
+            config_dictionary["_env"] = None
+            yaml.safe_dump(config_dictionary, f)
 
     def remove(self):
         self._path.unlink()
@@ -124,26 +134,30 @@ class Config:
 
     def upgrade_config_format(self):
         """Handles updating the older config format
-        - we default to oldest version with default values, and upgrade here
+        - we default to the oldest version with default values, and upgrade here
         """
-        # migrate older config files
-        if self.version == 1:
-            # capture_init()
-            self.version = 3
 
-            # If token exists check still valid and can login
+        # migrate older config files
+        if self.version in (1, 2, 3):
+            # If token exists check still valid and can login, use to get server props
             if self.token and self.token != DEFAULT_TOKEN:
-                from .api import ping
+                from .api.user import ping
 
                 with suppress(Exception):
-                    self.username = ping(config=self, cli_login=True, verbose=False)
+                    # get the email for v4 of spec
+                    self.email = ping(config=self, cli_login=True, verbose=False)
 
+                if not self.completed_action:
+                    # we could be on older version, but with a valid token
+                    # but haven't completed an action, so force it
+                    from .analytics import capture
+
+                    capture("CLI Login", config=self, with_token=True)
+
+            self.version = 4
             self.save()
-        elif self.version == 2:
-            # re-init against new server
-            # capture_init()
-            self.version = 3
-            self.save()
+        elif self.version == 4:
+            pass  # current
 
 
 # TODO - create a ConfigMgr singleton object?
@@ -178,7 +192,7 @@ def check_get_config() -> Config:
         if _config.token == DEFAULT_TOKEN:
             # still don't have a token set for the env, open up the browser
             if not _IN_PYTEST:
-                f = furl(path="/home/", origin=_config.server)
+                f = furl(path="/accounts/login/", origin=_config.server)
                 webbrowser.open(url=str(f), new=2)
             raise InvalidTokenError(
                 "Please sign-up and login - if you already have then please restart your Jupyter kernel/Python instance to initialize your new token"
